==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/items/RolesTableStartDateItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class RolesTableStartDateItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Role, UnitBox> {
	public _52_57_01804178925 _52_57_01804178925;
	public RolesTableStartDateItem._52_57_01804178925. StartDate startDate;

    public RolesTableStartDateItem(UnitBox box) {
        super(box);
        id("a_1586706557");
    }

    @Override
	public void init() {
		super.init();
		if (_52_57_01804178925 == null) _52_57_01804178925 = register(new _52_57_01804178925(box()).<_52_57_01804178925>id("a1788588551").owner(RolesTableStartDateItem.this));
		if (_52_57_01804178925 != null) startDate = _52_57_01804178925.startDate;
	}

	public class _52_57_01804178925 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public RolesTableStartDateItem._52_57_01804178925. StartDate startDate;

		public _52_57_01804178925(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (startDate == null) startDate = register(new StartDate(box()).<StartDate>id("a_1298093421").owner(RolesTableStartDateItem.this));
		}

		public class StartDate extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, UnitBox>  {

			public StartDate(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/items/RolesTableStartDateItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class RolesTableStartDateItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Role, UnitBox> {
	public _52_57_01804178925 _52_57_01804178925;
	public RolesTableStartDateItem._52_57_01804178925. StartDate startDate;

    public RolesTableStartDateItem(UnitBox box) {
        super(box);
        id("a_1586706557");
    }

    @Override
	public void init() {
		super.init();
		if (_52_57_01804178925 == null) _52_57_01804178925 = register(new _52_57_01804178925(box()).<_52_57_01804178925>id("a1788588551").owner(RolesTableStartDateItem.this));
		if (_52_57_01804178925 != null) startDate = _52_57_01804178925.startDate;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_52_57_01804178925 != null) _52_57_01804178925.unregister();
	}

	public class _52_57_01804178925 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public RolesTableStartDateItem._52_57_01804178925. StartDate startDate;

		public _52_57_01804178925(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (startDate == null) startDate = register(new StartDate(box()).<StartDate>id("a_1298093421").owner(RolesTableStartDateItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (startDate != null) startDate.unregister();
		}

		public class StartDate extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, UnitBox>  {

			public StartDate(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
